# Generated by roxygen2: do not edit by hand

export("domain<-")
export("fragment<-")
export("parameters<-")
export("path<-")
export("port<-")
export("scheme<-")
export(domain)
export(fragment)
export(get_credentials)
export(host_extract)
export(param_get)
export(param_remove)
export(param_set)
export(parameters)
export(path)
export(port)
export(puny_decode)
export(puny_encode)
export(scheme)
export(strip_credentials)
export(suffix_extract)
export(suffix_refresh)
export(tld_extract)
export(tld_refresh)
export(url_compose)
export(url_decode)
export(url_encode)
export(url_parse)
import(methods)
importFrom(Rcpp,sourceCpp)
importFrom(triebeard,longest_match)
importFrom(triebeard,trie)
useDynLib(urltools, .registration = TRUE)
